# ECE 106: Electricity and Magnetism

## MATH 117 review

!!! definition
    A definite integral is composed of:
    
    - the **upper limit**, $b$,
    - the **lower limit**, $a$,
    - the **integrand**, $f(x)$, and
    - the **differential element**, $dx$.

$$\int^b_a f(x)\ dx$$

The original function **cannot be recovered** from the result of a definite integral unless it is known that $f(x)$ is a constant.

## N-dimensional integrals

Much like how $dx$ represents an infinitely small line, $dx\cdot dy$ represents an infinitely small rectangle. This means that the surface area of an object can be expressed as:

$$dS=dx\cdot dy$$

Therefore, the area of a function can be expressed as:

$$S=\int^x_0\int^y_0 dy\ dx$$

where $y$ is usually equal to $f(x)$, changing on each iteration.

!!! example
    The area of a circle can be expressed as $y=\pm\sqrt{r^2-x^2}$. This can be reduced to $y=2\sqrt{r^2-x^2}$ because of the symmetry of the equation.
    
    $$
    \begin{align*}
    A&=\int^r_0\int^{\sqrt{r^2-x^2}}_0 dy\ dx \\
    &=\int^r_0\sqrt{r^2-x^2}\ dx
    \end{align*}
    $$

!!! warning
    Similar to parentheses, the correct integral squiggly must be paired with the correct differential element.

These rules also apply for a system in three dimensions:

| Vector | Length | Area | Volume | 
| --- | --- | --- | --- |
| $x$ | $dx$ | $dx\cdot dy$ | $dx\cdot dy\cdot dz$ |
| $y$ | $dy$ | $dy\cdot dz$ | |
| $z$ | $dz$ | $dx\cdot dz$ | |

Although differential elements can be blindly used inside and outside an object (e.g., area), the rules break down as the **boundary** of an object is approached (e.g., perimeter). Applying these rules to determine an object's perimeter will result in the incorrect deduction that $\pi=4$.

Therefore, further approximations can be made using the Pythagorean theorem to represent the perimeter.

$$dl=\sqrt{(dx^2) + (dy)^2}$$

### Polar coordinates

Please see [MATH 115: Linear Algebra#Polar form](/1a/math115/#polar-form) for more information.

In polar form, the difference in each "rectangle" side length is slightly different.

| Vector | Length difference |
| --- | --- |
| $\hat r$ | $dr$ |
| $\hat\phi$ | $rd\phi$ |

Therefore, the change in surface area can be approximated to be a rectangle and is equal to:

$$dS=(dr)(rd\phi)$$

!!! example
    The area of a circle can be expressed as $A=\int^{2\pi}_0\int^R_0 r\ dr\ d\phi$.
    
    $$
    \begin{align*}
    A&=\int^{2\pi}_0\frac{1}{2}R^2\ d\phi \\
    &=\pi R^2
    \end{align*}
    $$

If $r$ does not depend on $d\phi$, part of the integral can be pre-evaluated:

$$
\begin{align*}
dS&=\int^{2\pi}_{\phi=0} r\ dr\ d\phi \\
dS^\text{ring}&=2\pi r\ dr
\end{align*}
$$

So long as the variables are independent of each other, their order does not matter. Otherwise, the dependent variable must be calculated first.


!!! tip
    There is a shortcut for integrals of cosine and sine squared, **so long as $a=0$ and $b$ is a multiple of $\frac\pi 2$**:
    
    $$
    \int^b_a\cos^2\phi=\frac{b-a}{2} \\
    \int^b_a\sin^2\phi=\frac{b-a}{2}
    $$

The side length of a curve is as follows:

$$dl=\sqrt{(dr^2+(rd\phi)^2}$$

!!! example
    The side length of the curve $r=e^\phi$ (Archimedes' spiral) from $0$ to $2\pi$:
    
    \begin{align*}
    dl &=d\phi\sqrt{\left(\frac{dr}{d\phi}\right)^2 + r^2} \\
    \tag{$\frac{dr}{d\phi}=e^\phi$}&=d\phi\sqrt{e^{2\phi}+r^2} \\
    &=????????
    \end{align*}

Polar **volume** is the same as Cartesian volume:

$$dV=A\ dr$$

!!! example
    For a cylinder of radius $R$ and height $h$:
    
    $$
    \begin{align*}
    dV&=\pi R^2\ dr \\
    V&=\int^h_0 \pi R^2\ dr \\
    &=\pi R^2 h
    \end{align*}
    $$

### Moment of inertia

The **mass distribution** of an object varies depending on its surface density $\rho_s$. In objects with uniformly distributed mass, the surface density is equal to the total mass over the total area.

$$dm=\rho_s\ dS$$

The formula for the **moment of inertia** of an object is as follows, where $r_\perp$ is the distance from the axis of rotation:

$$dI=(r_\perp)^2dm$$

If the axis of rotation is perpendicular to the plane of the object, $r_\perp=r$. If the axis is parallel, $r_\perp$ is the shortest distance to the axis. Setting an axis along the axis of rotation is easier.

!!! example
    In a uniformly distributed disk rotating about the origin like a CD with mass $M$ and radius $R$:
    
    $$
    \begin{align*}
    \rho_s &= \frac{M}{\pi R^2} \\
    dm &= \rho_s\ r\ dr\ d\phi \\
    dI &=r^2\ dm \\
    &= r^2\rho_s r\ dr\ d\phi \\
    &= \rho_s r^3dr\ d\phi \\
    I &=\rho_s\int^{2\pi}_{\phi=0}\int^R_{r=0} r^3dr\ d\phi \\
    &= \rho_s\int^{2\pi}_{\phi=0}\frac{1}{4}R^4d\phi \\
    &= \rho_s\frac{1}{2}\pi R^4 \\
    &= \frac 1 2 MR^2
    \end{align*}
    $$

## Electrostatics

!!! definition
    - The **polarity** of a particle is whether it is positive or negative.

The law of **conservation of charge** states that electrons and charges cannot be created nor destroyed, such that the **net charge in a closed system stays the same**.

The law of **charge quantisation** states that charge is discrete — electrons have the lowest possible quantity.

Please see [SL Physics 1#Charge](/sph3u7/#charge) for more information.

**Coulomb's law** states that for point charges $Q_1, Q_2$ with distance from the first to the second $\vec R_{12}$:

$$\vec F_{12}=k\frac{Q_1Q_2}{||R_{12}||^2}\hat{R_{12}}$$

!!! warning
    Because Coulomb's law is an experimental law, it does not quite cover all of the nuances of electrostatics. Notably:
    
    - $Q_1$ and $Q_2$ must be point charges, making distributed charges inefficient to calculate, and
    - the formula breaks down once charges begin to move (e.g., if a charge moves a lightyear away from another, Coulomb's law says the force changes instantly. In reality, it takes a year before the other charge observes a difference.)

### Dipoles

An **electric dipole** is composed of two equal but opposite charges $Q$ separated by a distance $d$. The dipole moment is the product of the two, $Qd$.

The charge experienced by a positive test charge along the dipole line can be reduced to as the ratio between the two charges decreases to the point that they are basically zero:
$$\vec F_q=\hat x\frac{2kQdq}{||\vec x||^3}$$

## Maxwell's theorems

Compared to Coulomb's law, $Q_1$ creates an electric field around itself — each point in space is assigned a vector that depends on the distance away from the charge. $Q_2$ *interacts* with the field. According to Maxwell, as a charge moves, it emits a wave that carries information to other charges.

The **electric field strength** $\vec E$ is the force per unit *positive* charge at a specific point $p$:

$$\vec E_p=\lim_{q\to 0}\frac{\vec{F}}{q}$$

Please see [SL Physics 1#Electric potential](/sph3u7/#electric-potential) for more information.

### Electric field calculations

If charge is distributed over a three-dimensional object, integration similar to moment of inertia can be used. Where $dQ$ is an infinitely small point charge at point $P$, $d\vec E$ is the electric field at that point, and $r$ is the vector representing the distance from any arbitrary point:

$$d\vec E = \frac{kdQ}{r^2}\hat r$$

!!! warning
    As the arbitrary point moves, both the direction and the magnitude of the distance from the desired point $P$ change (both $\hat r$ and $r$).

Generally, if a decomposing the vector into Cartesian forms $d\vec E_x$, $d\vec E_y$, and $d\vec E_z$ is helpful even if it is easily calculated in polar form because of the significantly easier ability to detect symmetry in the shape. Symmetry about the axis allows deductions such as $\int d\vec E_y=0$, which makes calculations easier.

In a **one-dimensional** charge distribution (a line), the charge density is used in a similar way as moment of inertia's surface density:

$$dQ=\rho_\ell d\ell$$

**Two-dimensional** charge distributions are more or less the same, but polar or Cartesian forms of the surface area work depending on the shape.

$$dQ=\rho_s dS$$

!!! example
    A rod of uniform charge density and length $L$ has a charge density of $p_\ell=\frac{Q}{L}$.

1. Determine the formula for the charge density $\rho$
2. Choose an origin and coordinate system (along the axes of the object when possible)
3. Choose an arbitrary point $A$ on the charge
4. Create a right-angle triangle with $A$, the desired point, and usually the origin
5. Attempt to find symmetry
6. Solve

## Gauss's law

!!! definition
    - A **closed surface** is any closed three-dimensional object.
    - **Electric flux** represents the number of electric field lines going through a surface.

At an arbitrary surface, the **normal** to the plane is its vector form:

$$\vec{dS}=\vec n\cdot dS$$

The **electric flux density** $\vec D$ is an alternate representation of electric field strength. In a vacuum:

$$\vec D = \epsilon_0\vec E$$

**Electric flux** is the electric flux density multiplied by the surface area at every point of an object.

$$\phi_e=\epsilon_0\int_s\vec E\bullet\vec{dS}$$

The flux from charges outside a closed surface will **always be zero at the surface**. A point charge in the centre of a closed space has a flux equal to its charge. Regardless of the charge distribution or shape, the **total flux** through a closed surface is equal to the **total charge within** the closed surface.

$$\oint \vec D\bullet\vec{dS}=Q_\text{enclosed}$$

This implies $\phi_e>0$ is a net positive charge enclosed.

!!! warning
    Gauss's law only applies when $\vec E$ is from all charges in the system

### Charge distributed over a line/cylinder

!!! warning "Limitations"
    To apply this strategy, the following conditions must hold:
    
    - $Q$ must not vary with the length of the cylinder or $\phi$
    - The charge must be distributed over either a cylindrical surface or the volume of the cylinder.
    - In the real world, $r$ must be significantly smaller than $L$ as an approximation.
    - The strategy is more accurate for points closer to the centre of the wire.

Please see [Maxwell's integral equations#Gauss's law](https://en.wikiversity.org/wiki/MyOpenMath/Solutions/Maxwell%27s_integral_equations) for more information.

**Outside** the radius $R$ of the cylinder of the Gaussian surface, the enclosed charge is, where $L$ is the length of the cylinder:

$$Q_{enc}=\pi R^2\rho_0L$

such that the field at any radius $r>R$ is equal to:

$$\vec E(r)=\frac{\rho_0\pi R^2}{2\pi\epsilon_0r}\hat r$$

**Inside** the radius $R$ of the cylinder, the enclosed charge depends on $r$. For a uniform charge density:

$$Q_{enc}=\pi r^2\rho_0L$$

such that the field at any radius $r< R$ is equal to:

$$\vec E(r)=\frac{\rho_0}{2\epsilon_0}r\hat r$$

The direction of $\vec E$ should always be equal to that of $\vec r$. Generally, where $lim$ is $r$ if $r$ is *inside* the cylinder or $R$ otherwise, $\rho_v$ is the function for charge density based on radius, and $r_1$ is hell if I know:

$$\epsilon_0 E2\pi rL=\int^{lim}_0\rho_v(r_1)2\pi r_1L\ dr_1$$

### Charge distributed over a plane

!!! warning
    To apply this strategy, the following conditions must hold:
    
    - $Q$ must not vary with the lengths of the plane
    - The charge must be distributed over a plane or slab
    - In the real world, the thickness $z$ must be significantly smaller than the lengths as an approximation

Where $\rho_v$ is an **even** surface density function and $lim$ is from $0$ to $z$ if the desired field is outside of the charge, or $0$ to field height $h$ if it is inside the charge:

$$\epsilon_0 E=\int_{lim}\rho_v\ dh_1$$

Any two points have equal electric fields regardless of distance due to the construction of a uniform electric field.

Where $\rho_v$ is not an even surface density function, $d$ is the thickness of the slab, and $E$ is the electric field **outside** the slab:

$$2\epsilon_0E = \int^d_0\rho_v(A)dh_1$$

Where $E$ is the electric field **inside** the slab at some height $z$:

$$E=\frac{\rho_0}{4\epsilon_0}(2z^2-d^2),0\leq z\leq d$$

If $E$ is negative, it must point opposite the original direction ($\hat z$).

Generally:

1. Determine $\vec E$ outside the slab.
2. Set one outside surface and one inside surface as a pillbox and apply rules.

## Electrostatic potential

At a point $P$, the electrostatic potential $V_p$ or voltage is the work done per unit positive test charge from infinity to bring it to point $P$ by an external agent.

$$
V_p=\lim_{q\to 0^+}\frac{W_i}{q} \\
W_I=\int^p_\infty\vec F_I\bullet \vec{dl}=\Delta U=QV_p
$$

Because the desired force acts opposite to the force from the electric field, as long as $\vec E$ is known at each point:

$$
V_p=-\int^p_\infty\vec E\bullet\vec{dl} \\
V_p=-\int^p_\infty E\ dr
$$

The work done only depends on initial and final positions — it is conservative, thus implying Kirchoff's voltage law.

Where $\vec dl$ is the path of the test charge from infinity to the point, and $\vec dr$ is the direct path from the origin through the point to the charge, because $dr=-dl$:

$$\vec E\bullet\vec{dl}=Edr$$

Therefore, the potential due to a point charge is equal to (the latter is true only if distance from charge is always constant, regardless of distribution):

$$V_p=-\int^p_\infty\frac{kQ}{r^2}dr=\frac{kQ}{r}$$

**Positive** charges naturally move to **lower** potentials ($V$ decreases) while negative charges do the opposite. Potential energy always decreases.

In order to calculate the voltage for charge distributions:

- If $\vec E$ is easy to find via Gauss law:

$$V_p=-\int^p_\infty\vec E\bullet\vec{dl}$$

- If the charge is asymmetric:

$$V_p=\int_\text{charge dist}\frac{kdQ}{r}$$

The electric field always points in the direction of **lower** potential, and is equal to the **negative gradient** of potential.

$$\vec E=-\nabla V$$

If $\vec E$ is constant:

$$\vec E=\frac{Q_{enc\ net}}{\epsilon_0\oint dS}$$

The **superposition** principle allows potential due to different charges to be calculated separately and summed together to achieve the same result.

## Conductors

An **ideal conductor** has electrons loosely bound to atoms such that an electric field causes them to freely move by $F=Q_e E$. However, this assumes that there are infinite electrons in the conductor, and that the electrons will move with **zero resistance** to the surface of the conductor but **not leave it**.

A conductor placed in an external electric field will cause electrons to hop from atom to atom to reach the surface, charging one surface negatively and the other positively. The **induced electric field** from this imbalance opposes the external field force, slowing down electron movement until equilibrium is reached.

$$\text{equilibrium}\iff \vec E_{ext}+\vec E_{ind}=\vec 0$$

At equilibrium, **every point in the conductor is equipotential**. Gauss's law implies that there is no volume charge inside a conductor.

At its surface, $\vec E$ tangent to the surface must be zero. Normal to the surface:

$$|\vec E_N|=\frac{|\rho_0|}{\epsilon_0}$$

- $\rho_0$ is negative if field lines **enter** the conductor.
- $\rho_0$ is positive if field lines exit the conductor.

### Conductor cavities

A cavity surface must have **zero surface charge**. This creates a Faraday cage — outside fields cannot affect the cavity, but fields from the cavity can affect the outside world.

If there is a fixed/non-moving charge $Q$ in the cavity:

- $\vec E=0$ inside the conductor, so the boundary surface charge must be $-Q$.
- Electrons are taken from the surface, so the surface charge outside the conductor must be $Q$, propagating the effect of the charge to the outside world.

### Ground

A **ground** is a reservoir or sink of charges that never changes, regardless of the quantity added or removed from it. At the connection point, $V=0$ is always guaranteed.

Grounding a conductor means that it takes charges from the ground to balance an internal charge, neutralising it.

A charge released into a conductor (e.g., battery into wire) will always go to the outside surface, regardless of the point of insertion. Two charged objects connected by a thin conductor will redistribute their charge such that:

- their potentials are equal
- conservation of charge is followed.

This implies that a larger object has more charge, but a smaller object has a denser charge and thus stronger electric field.

$$Q_1=\frac {R_1} {R_2}Q_2$$

!!! example
    For two spheres, as $\rho=\frac{Q_1}{4\pi R^2}$:
    
    $$\rho_1=\frac {R_2} {R_1}\rho_2$$

A non-uniform object, such as a cube, will have larger charge density / stronger electric field at sharper points in its shape. Symmetrical surfaces always have uniform charge density.

!!! warning
    An off-centre charge in a cavity will require a non-uniform induced charge to cancel out the internal field, but the external surface charge will be uniform (or non-uniform if the surface is odd).

### Nutshell

**Inside** a conductor:

- $\vec E=0$
- $\Delta V=0$
- $\rho_v=0$

Inside a cavity, if there exists an external field:

- $\vec E=0$
- $\rho_s=-Q$
- $\rho_{s\ outer}=Q$

The inner surface charge distribution matches that of the inner charge, but the outer surface charge distribution is dependent only on the shape of the conductor.

On conductor surfaces, the only $\vec E$ is **normal** to the surface and dependents on the shape of the surface.

$$|\vec E_N|=\frac{|\rho_s|}{\epsilon_0}$$

Grounding a conductor neutralises any free charges.

In slabs, as $A>>d$, assume $Q$ is uniformly distributed.

To solve systems:

- Assigning charge **density** is easier with sheets
- Assigning **charges** is easier with cylinders/spheres

## Dielectrics

!!! definition
    - An **insulator** has electrons tightly bound to atoms.

### Polarisation

Polarisation is the act of inducing a dipole to a lesser extent than conductors. The induced field cannot reduce $\vec E$ inside the insulator to zero, but it will reduce its effects. The **polarisation vector** $\vec P$ is an average of the effects of all induced fields on a certain point inside a volume.

$$\vec P=\lim_{\Delta V\to 0}\frac{\sum^{N\Delta v}\vec p_i}{\Delta v}$$

where:

- $\Delta v\approx dv$ is the volume of the insulator
- $p_i$ is the dipole moment at a point
- $N$ is the total number of atoms in the volume

Polarisation is proportional to electric field and the **electric susceptibility** $X_e$ of a material to external fields.

$$\boxed{\vec P=\epsilon_0X_e\vec E}$$

The **relative permittivity** $\epsilon_r$ of a material is the ratio of decreasing $\vec E$ inside a medium relative to free space.

$$\epsilon_r=1+X_e$$

The new **flux density** formula includes polarised charges, so now $Q_{enc}$ includes **only free charges** (i.e., not polarised charges).

$$\boxed{\vec D=\epsilon_0\vec E+\vec P=\epsilon_0\epsilon_r\vec E}$$

$$\boxed{\oint\vec D\bullet\vec{dS}=Q_{enc,free}}$$

In uniform charge distributions, the surface charge density is related to its polarisation. Where $\hat n$ is the unit normal of the surface:

$$\rho_s=\vec P\bullet\hat n$$

### Boundary conditions

Regardless of permittivity, the $\vec E$ **tangential to the boundary** between two materials must be equal.

## Capacitors

!!! definition
    - A **capacitor** is a device that uses the capacitance of materials to store energy in electric fields. It is usually composed of two conductors separated by a dielectric.
    
**Capacitance** is a measurement of the charge that can be stored per unit difference in potential.

$$\boxed{Q=C\Delta V}$$

To determine $C$:

1. Place a positive and a negative charge on conductors
2. Determine charge distribution
3. Determine $\vec E$ between the conductors
4. Find a path from the negative to the positive conductor and determine voltage

??? example
    For two plates separated by distance $d$, with charges of $+Q$ and $-Q$, and a dielectric in between with permittivity $\epsilon_0\epsilon_r$:
    
    - Clearly $\rho_0=\frac Q A$ as sheets must have uniform distribution. $-\rho_0$ is on the negative plate.
    - From Gauss' law, creating a Gaussian surface outside the capacitor to between the plates gives $DA=\rho_0A$.
    - $D=\epsilon_0\epsilon_rE$ gives $E=\frac{\rho_0}{\epsilon_0\epsilon_r}$
    - Sheets have uniform fields, thus $\Delta V=Ed$
    - Finally, $C=\epsilon_0\epsilon_r\frac A d$

!!! warning
    If three dielectrics with different permittivities are allowed to touch each other, they will create **fringe fields** at their intersection that destroy the boundary condition.

### Capacitors and energy

The stored energy inside capacitors is the same as any other energy.

$$\boxed{U_e=\frac 1 2CV^2}$$

Much like VIR, it's usually easier to work with the form of the equation that has squared constants.

$$U_e=\frac 1 2 \frac {Q^2}{C}=\frac 1 2 QV$$

Adding dielectrics increases capacitance but decrease stored energy.

## Magnetism

All magnetic field lines are closed, i.e., they all return to the same magnetic object, much like a dipole. All lines must be perpendicular to the surface:

$$\oint\vec B\bullet\vec{dS}=0$$

Per **Biot-Savart's law**, magnets are complicated.

$$\boxed{d\vec B_p=\frac{\mu_0}{4\pi}I\frac{\vec {dl}\times\hat r}{|r|^2}}$$

where:

- $\mu_0$ is the magnetic permeability of free space
- $\hat r$ is the unit vector pointing from an arbitrary point of a wire to the desired point
- $I$ is current
- $dl$ follows the direction of current

The final direction can be determined in advance with the **right-hand rule**. Therefore, magnitude can be reduced to:

$$|dl\times\hat r|=|dl||\hat r|\sin\theta=|dl|\sin\theta$$

### Calculations

1. Define coordinate system
2. Go to some arbitrary point $A$ on a coordinate axis such that $r=AP$
3. Determine magnitude of the cross product
4. Determine final magnetic field direction (should be constant)
5. Rewrite equation in terms of one variable (usually $\theta$)
6. Integrate

### Selenoids

It's easiest to place the origin at the target point.

A selenoid with $N$ turns around a coil of length $L$ has density $n$, and has parallel electric fields inside.

$$n=\frac N L$$

The effective current of a selenoid for magnetic purposes is the sum of all currents.

$$\boxed{I_{eff}=ndzI}$$

where:

- $dz$ is the axis in the direction of current
- $I$ is current

This can be substituted directly into Biot-Savart's law, although definite integration should be done **in the direction of the axis** (from the desired point to the farthest point of the selenoid).

### Velocity and current

Biot-Savart's law can be applied to moving charges:

$$I\cdot \vec{dl}=\frac{dq\cdot dl}{dt}=dq\cdot \vec v$$

### Ampere's law

!!! definition
    - **Drift velocity** is the average speed of electrons through a material.

The **current density** $\vec J$ is the amount of charge per unit time that flows through a unit area of a cross section.

$$\boxed{\vec J=nq\vec u=\rho_v\vec u}$$

where:

- $\vec u$ is drift velocity
- $n$ is the charge per unit volume
- $q$ is the total charge

Ohmic resistors have current density proportional to electric field by a material's **conductivity** $\sigma$.

$$\vec J=\sigma\vec E$$

Resistivity is related to conductivity: $\rho=\frac 1\sigma$

Integrating over a cross section returns current:

$$\boxed{I=\oint\vec J\bullet\vec{dS}}$$

**Ampere's law** asserts that magnetic flux due to all currents is equal to current enclosed inside a closed boundary/loop.

$$
\boxed{\begin{align*}
\oint\vec B\bullet\vec{dl}&=\mu_0I_{enc} \\
&=\mu_0\oint\vec J\bullet\vec{dS}
\end{align*}}
$$

where:

- $dl$ is the line along the loop/boundary in an arbitrary direction
- $I_{enc}$ is the sum of all enclosed currents

$dl$ (along the loop) and $dS$ are related in direction with each other per the **right hand rule**.

!!! warning
    Ampere's law is only true in when dealing with DC.

For each enclosed $I$, if its direction is:

- the same as $\vec dS$, it is positive in the sum term
- opposite $\vec dS$, it is negative in the sum term

1. Use $dl$ to find $dS$ or vice versa
2. Determine $I_{enc}$
3. Solve

The angle of a cut to a surface does not affect any equations and can be treated identically. Any imaginary closed loop such that $\vec B$ **is constant over the loop and parallel to the loop** is usable with Ampere's law as $B$ can be reduced to a constant scalar.

The geometries that work include:

- Infinite cylinders with $J$ that may vary with $r$ but not $\phi$
- Infinite sheets/slabs where $J$ may vary with $z$ but not $x,y$
- Infinite selenoids
- Toroids (a selenoid bent into a donut shape)

1. Create a cross-section perpendicular to the current and determine if symmetry of the loop can meet conditions for geometry
2. Choose $dl$ in the direction of $B$ (counterclockwise)
3. Determine $dS$ (out of the page) and apply Ampere's law

$$\hat\phi=\hat z\times\hat r_1$$

!!! warning
    A spinning cylinder rotates faster along its outer ring, forcing an integral setup.
   
### Faraday's law

Faraday's law states relates magnetic flux similarly to electric flux. Where $s$ is the open surface bounded by the conductor:

$$\phi_m=\int_s\vec B\bullet\vec{dS}$$

A flux that changes with time results in an **induced voltage** across the terminals of the conductor. Per Faraday's law of electromagnetic induction, magnetic energy is convertible to electric energy.

$$V_{ind}=-\frac{d}{dt}\phi_m$$

As the electric field is always perpendicular to a magnetic field, this indicates that it will curl around a straight magnetic field.

Relating $dl$ and $dS$ with the right-hand rule accounts for **Lenz's law**, which creates a $\vec E$ to create a $\vec B$ to oppose the change in $\phi_m$ that created the current.

$$\boxed{\oint\vec E\bullet\vec{d\ell}=\frac{d}{dt}\int\vec B\bullet\vec{dS}}$$

If there is a conducting loop in a time-varying magnetic field, a $V_{ind}$ is formed such that the current is in the direction of the induced field:

$$V_{ind}=\oint\vec E\bullet\vec{d\ell}=-\frac{d}{dt}\int\vec B\bullet\vec{dS}$$

Time-varying magnetic fields are formed if the field or charge is moving or if bounds change.

## Inductance

Kirchoff's voltage law is a simplification of Faraday's law, valid when there is no fluctuating magnetic field within the closed loop, so it's used with low frequency waves with less time variation.

The **inductance** is the flux travelling through a medium over its current.

$$L=\frac{\phi_m}{i}$$

If there are $N$ loops in a selenoid, where $\Lambda=N\phi_m$ is the total flux/**flux linkage**, $i$ is the current in one loop, and $I$ is the current of all loops:

$$L=\frac{\phi_m}{i}=\frac{\Lambda}{I_{eff}}$$

The **energy density** per unit volume is $u_m$.

$$u_m=\frac 1 2 \frac {B^2}{\mu_0}$$

The **total work** $U_m$ done to charge current from $0$ to $I$ is related to energy density.

$$U_m=\sqrt u_m=\frac 1 2 LI^2$$

$$\boxed{\frac 1 2 LI^2=\frac 1 2\int_{volume}U_mdV}$$

### Self-inductance

A magnetic flux that passes through the current that created it will induce voltage if $I$ changes.

**Mutual inductance** is wireless charging as changing current in one coil produces a changing magnetic flux in another, creating a voltage $\epsilon_{1\to 2}$.

$$V_{ind}=\epsilon_{1\to 2}=N_2\frac{d\phi_{1\to 2}}{dt}=-\frac{d}{dt}\int \vec B_1\bullet\vec{dS}_2$$

The mutual inductance is the rate of change of magnetic flux proportional to the rate of change of current. It is equal regardless of direction.

$$\boxed{M_{1\to 2}=\frac{N_2\phi_{1\to 2}}{I_1}}$$
