# ECE 140: Linear Circuits

## Voltage, current, and resistance

Please see [SL Physics 1#Electric potential](/g11/sph3u7#electric-potential) for more information on voltage.

Please see [SL Physics 1#5.2 - Heating effect of electric currents](/g11/sph3u7/#52-heating-effect-of-electric-currents) for more information on current.

Please see [SL Physics 1#Resistance](/g11/sph3u7/#resistance) for more information on resistance.

**Electric charge** $Q$ quantises the charge of electrons and positive ions, and is expressed in coulombs (**C**).

Objects with charge generate electric fields, thus granting potential energy that is released upon proximity to another charge.

!!! warning
    Voltage and current are capitalised in **direct current only** ($V$, $I$). In general use, their lowercase forms should be used instead ($v, $i$).

**Voltage** is related to the change in energy ($dw$) over the change in charge ($dq$), or alternatively through Ohm's law:

$$i=\frac{dw}{dq}=\frac{i}{R}$$

**Current** represents the rate of flow of charge in amps (**A**). Conventional current moves opposite electron flow because old scientists couldn't figure it out properly.

$$i=\frac{dq}{dt}\approx \frac{\Delta q}{\Delta t}$$

### Power

Power represents the rate of doing work, in unit watts ($\pu W$, \pu{J/s})

$$P=\frac{dw}{dt}$$

It is also directly related to voltage and current:

$$P=vi$$

Much like relative velocity, power is directional and relative, with a positive sign indicating the direction of conventional current.

$$P_{CB}=-P_{BC}$$

In a closed system, conservation of energy applies:

$$\sum P_\text{in}=\sum P_\text{out}$$

The **ground** is the "absolute zero" voltage with a maximum potential difference. It is also known as the "reference voltage".

### Independent energy sources

!!! definition
    - A **ground** is the reference point that all **potential differences are relative to**.

A **generic voltage source** provides a known potential difference between its two terminals that is defined by the source. The resultant current can be calculated.

<img src="https://upload.wikimedia.org/wikipedia/commons/f/ff/Voltage_Source.svg" width=100>(Source: Wikimedia Commons)</img>

A **generic current source** provides a known amperage between its two terminals that is defined by the source. The resultant voltage can be calculated.

<img src="https://upload.wikimedia.org/wikipedia/commons/b/b2/Current_Source.svg" width=100>(Source: Wikimedia Commons)</img>

!!! tip
    A current in the **positive direction** indicates that the source is releasing power (is a source). Otherwise, it is consuming power (is a load).

### Dependent energy sources

A **dependent <&ZeroWidthSpace;T: voltage | current> source** has a **T** dependent on the voltage or current elsewhere in the circuit. $k$ is a function that is likely but not guaranteed to be linear.

$$
v=kv_0\ |\ ki_0 \\
i=kv_0\ |\ ki_0
$$

<img src="https://upload.wikimedia.org/wikipedia/commons/5/55/Voltage_Source_%28Controlled%29.svg" width=100>(Source: Wikimedia Commons)</img>

<img src="https://upload.wikimedia.org/wikipedia/commons/f/fe/Current_Source_%28Controlled%29.svg" width=100>(Source: Wikimedia Commons)</img>

### Applications

A **cathode ray tube** produces an electron beam of variable intensity depending on the input signal. Electrons are deflected by the screen to produce imagery.

<img src="/resources/images/crt.png" />

### Resistance

A **resistor** *always absorbs power*, so must be oriented such that current goes into the positive sign.

According to Ohm's law, the voltage, current, and resistance are related:

$$v=iR$$

The **conductance** of a resistor is the inverse of its resistance, and is expressed in siemens ($\pu{S}$)

$$G=\frac 1 R = \frac I V$$

Therefore, power can be expressed by manipulating the equations:

$$
\begin{align*}
P &= IR^2 \\
&= V^2G \\
&= \frac{V^2}{R}
\end{align*}
$$

## Kirchhoff's laws

!!! definition
    - A **node** is any point in the circuit to which 3+ elements are *directly* connected (i.e., all junctions).
    - A **supernode** is any connected group in the circuit to which 3+ elements are *directly* connected.
    - A **loop** is any closed path of elements.

Kirchhoff's **current law** states that the sum of all current entering a node must be zero, where positive indicates current entrance.

$$\sum i_\text{entering node}=0$$

Kirchoff's **voltage law** states that the sum of all voltage in a **closed loop** must be zero.

$$\sum v_\text{loop}=0$$

### Nodal analysis

Nodal analysis uses the voltages at the **nodes** instead of elements to calculate things in a three-step process:

1. Determine a reference node with $v=0$ and stick a ground out of that node.
2. Use KCL and Ohm's law on non-reference nodes to get their currents in terms of the reference node.
3. Solve the system of equations with the formula below.

On either side of a resistor, the current flowing that entire segment can be determined via the following formula:

$$i=\frac{v_\text{higher}-v_\text{lower}}{R}$$

### Mesh analysis

!!! definition
    - A **mesh** is a loop with no inner loops.
    - A **supermesh** is a combination of multiple meshes that share a common current source.

Mesh / loop analysis is used to determine unknown currents, using KVL instead of KCL to create a system of equations.

1. Assign mesh currents to each loop.
2. Use KVL and Ohm's law to get voltages in terms of mesh currents.
3. Solve the system of equations.

It may be easier to delete the branch of the current source in supermeshes, treating the region as one mesh with multiple mesh currents.

## Linearity

Circuits are linear if and only if their voltages, resistances, and currents can be expressed in terms of linear transformations of one another. They contain only linear loads, linear dependent sources, and independent souces.

$$\text{output}\propto\text{input}+C$$

!!! example
    Halving voltage must halve current (or at least halve it relative to a base current / voltage).

### Superposition

In linear circuits, the superposition principle states that the voltage/current through an element is equal to the sum of the voltages/currents from each independent source alone.

$$
v=\sum v_x \\
i=\sum i_x
$$

To do so, each unused independent source should be replaced with a short circuit (voltage) or an open circuit (current).

### Source transformation

In linear circuits, a voltage source in series with a resistor can be replaced by a current source in parallel to that resistor (or vice versa), so long as Ohm's law is followed for the replacement:

$$v_1=i_2R$$

The arrow of the current source must point in the positive direction of the voltage source. This can also be used with dependent sources.

### Thevenin's theorem

Any part of a circuit including an independent source can be replaced with exactly one voltage source and a resistor in series. Two circuits are **Thevenin equivalent** if their $\lambda$ are equal in $V=\lambda I$.

If there are no dependent sources, all independent sources should be removed to determine the resistance across points $AB$:

$$R_{Th}=R_{AB}$$

Otherwise, $V_{AB}$ and $I_{AB}$ should be found by repeating these steps:

1. Cut off the load (open if finding voltage, short if finding current)
  - If dependent sources depend on elements inside the load branch, zero them
2. Use analysis to determine the desired quantity

Across the load:

$$
I_L=\frac{V_{Th}}{R_{Th}+R_L} \\
V_L=R_LI_L = \frac{R_L}{R_{Th}+R_L}V_{Th}
$$

!!! warning
    A negative resistance $R_{L}$ indicates that the load supplies power.

### Maximum power transfer

To maximise the power transferred from the circuit to the load, $R_L$ should be equal to $R_{Th}$.

$$P_L=v_Li_L$$

## Operational amplifiers

The entire op-amp follows KCL. The output current is the sum of all input currents (the two inputs and V+, V-).

Where $\Delta V$ is the difference between the two inputs, and $A$ is the gain of the opamp:

$$\boxed{V_{out}=A\Delta V}$$

Output voltage is limited by the maximum/minimum of the power supply $V_cc$.

If the output is fed directly into the inverting input (as a **voltage follower**), the gain is ignored and results in $V_{out}=\Delta V$.

An **ideal opamp** has no input current and equal voltages entering the opamp.

$$
\boxed{i_1=i_2=0} \\
\boxed{v_1=v_2}
$$

**Inverting amplifiers** feed their input back and return negative voltage.

$$V_{out}=-\frac{R_f}{R_i}V_{in}$$

<img src="https://upload.wikimedia.org/wikipedia/commons/4/41/Op-Amp_Inverting_Amplifier.svg" width=700>(Source: Wikimedia Commons)</img>

**Non-inverting amplifiers** moves the voltage source to the non-inverting terminal.

$$v_o=\left(1+\frac{R_f}{R_i}v_i\right)$$

<img src="https://upload.wikimedia.org/wikipedia/commons/6/66/Operational_amplifier_noninverting.svg" width=700>(Source: Wikimedia Commons)</img>

**Voltage followers** have either $R_f=0$ or $R_i=\infty$, so:

$$v_o=v_i$$

<img src="https://upload.wikimedia.org/wikipedia/commons/f/f7/Op-Amp_Unity-Gain_Buffer.svg" width=700>(Source: Wikimedia Commons)</img>

A **summing amplifier** splits an inverting amplifier's input into multiple voltage sources in series with resistances, all parallelised into the opamp:

$$v_o=-R_f\left(\frac{V_1}{R_1}+\frac{V_2}{R_2}+\frac{V_3}{R_3}\right)$$

<img src="https://upload.wikimedia.org/wikipedia/commons/3/3e/Op-Amp_Summing_Amplifier.svg" width=700>(Source: Wikimedia Commons)</img>

A **difference amplifier** is funky. To ensure that output is zero when inputs are equal, $\frac{R_1}{R_2}=\frac{R_3}{R_4}$.

$$v_o=\frac{R_2}{R_1}(v_2-v_1)$$

<img src="https://upload.wikimedia.org/wikipedia/commons/a/a2/Op-Amp_Differential_Amplifier.svg" width=700>(Source: Wikimedia Commons)</img>


## Capacitors

Capacitors are open circuits in DC that store energy in electric fields. Capacitance is measured in **farads** ($\pu{1 F = 1 C/V}$).

Where $A$ is the cross-section area of the wire, $\epsilon$ is the permittivity of the dielectric, and $d$ is the distance between plates:

$$C=\frac{\epsilon A}{d}$$

Capacitors charge only when power is positive ($VI>0$).

For linear capacitors:

$$i=C\frac{dv}{dt}$$

$$v(t)=\frac{1}{C}\int^t_{t_0}i(t)dt+v(t_0)$$

The energy in a capacitor can be interconverted.

$$U=\frac 1 2 CV^2$$

Capacitor rules are the opposite of resistor rules.

- In parallel: $C_{eq} = C_1 + C_2 + ...$
- In series: $\frac{1}{C_{eq}} = \frac{1}{C_1} + \frac{1}{C_2} + ...$

## Inductors

Inductors store energy in their magnetic field. Inductance is measured in **henrys** ($\pu{1 H = 1 V\cdot S/A}$). An ideal inductor has zero resistance and capacitance

Where $L$ is the inductance (opposition of charge flow):

$$V=L\frac{di}{dt}$$

Inductor rules are the same as resistor rules.

### Selenoids

Selenoids have an inductance based on their cross sectional area $A$, number of coils $N$, length $\ell$, and core permeability $\mu$:

$$L=\frac{N^2\mu A}{\ell}$$

Where $i(t_0)$ is the total current for $-\infty<t<t_0$

$$i=\frac 1 L\int^t_{t_0}v(t)dt + i(t_0)$$

Much like capacitors, inductors have energy now based on current.

$$U=\frac 1 2 Li^2$$

## First-order circuits

!!! definition
    - An **RC** circuit contains a resistor and a capacitor.
    - An **RL** circuit contains a resistor and an inductor.
    - **First-order circuits** contain derivatives.
    - A **source-free circuit** assumes that energy already exists in the capacitor/inductor and no external energy enters the system.
    - The **circuit response** is the behaviour of the circuit after excitation.
    - The **natural response** is the behaviour of the circuit without external excitation.

The **time constant** $\tau$ is the time requirement for the circuit to decay to $\frac 1 e$ of its initial value. For RC circuits:

$$\tau=RC$$

$$v(t)=v_0e^{-t/\tau}$$

RL circuits have very similar formulae:

$$\tau=\frac L R$$

$$i(t)=i_0e^{-t/\tau}$$

### Singularity functions

The **unit step function** is a stair that is undefined at zero.

$$
u(t)=\begin{cases}
0 & \text{if }t<0 \\
1 & \text{if }t>0
$$

The **unit impulse/delta function** is the derivative of the unit step function.

$$
\delta(t)=\frac{d}{dt}u(t)=\begin{cases}
0 & \text{if }t<0 \\
\text{undefined} & \text{if }t=0 \\
0 & \text{if }t>0
$$

The sudden spike at $t=0$ means that $\int^{0+}_{0-}\delta(t)dt=1$.

This function is related to signal strength. For the function $a\delta(t+y)$, changing $y$ shifts the phase while shifting $a$ shifts amplitude.

To obtain $f(t)$ at the impulse:

$$\int^b_a\delta(t-t_0)dt=f(t_0$$


The **unit ramp function** is the integral of the unit step function.


\begin{align*}
r(t)&=\int^1_{-\infty}u(\lambda)d\lambda=tu(t) \\
&=\begin{cases}
0 & \text{if }t\leq 0 \\
t & \text{if }t\geq 0
\end{cases}
\end{align*}

## Circuit responses

The total response to a circuit $V$ can be expressed as various combinations of:

- the natural response, $v_n=v_0e^{-t/\tau}$
- the forced response (induced) $v_f=v_s(1-e^{-t\tau})$
- the temporary response, $(v_0-v_s)e^{-1/t}$
- the permanent/steady-state response, $v_s$

$$
v(t)=\begin{cases}
v_0 & \text{if }t<0 \\
v_s+(v_0-v_s)e^{-t/\tau} &\text{if }t>0
\end{cases}
$$

In general, for current and voltage ($x$), where $x_\infty$ is the final value and $x_0$ is the initial value:

$$\boxed{x(t)=x(\infty)+[x(0)-x(\infty)]^{-t/\tau}}$$

A delayed response by $t_0$ shifts $t$ to $t-t_0$ and $x(0)$ to $x(t_0)$.

## Alternating current

Where $V_m$ is the amplitude of the voltage and $\omega$ is its angular frequency:

$$v(t)=V_m\sin(\omega t)$$

For a sinusoid's period $T$, a circuit is period if and only if, for all $n\in\mathbb Z$:

$$v(t)=v(t+nT)$$

### Phasors

The **phasor** is the complex number vector version of the sinusoid in the time domain.

$$v(t)=\text{Re}(\bold Ve^{j\omega t})$$

Please see [MATH 115: Linear Algebra#Geometry](/1a/math115/#geometry) for more information.

$$\bold V=V_m^{j\phi}$$

To transform time domains to frequency domains:

| Sinusoidal | Phasor |
| --- | --- |
| $V_m\cos(\omega t+\phi)$ | $V_m\angle\phi$ |
| $V_m\sin(\omega t+\phi)$ | $V_m\angle\phi-90^\circ$ |

The **derivative** of a phasor is itself multiplied by $j\omega$.

$$\frac{d}{dt}\bold V=j\omega\bold V$$

Adding sinusoids of the **same frequency** ($\omega$) is equivalent to adding their phasors.

If $\bold V$ and $\bold I$ are phasors:

- Inductors: $\bold V=j\omega L\bold I$ ($\bold I$ lags $\bold V$ by 90°)
- Capacitors: $\bold V=\frac{I}{j\omega C}$ ($\bold V$ lags $\bold I$ by 90°)

The **scalar** quantity of **impedance** represents the opposition to electron flow, measured in ohms.

$$Z=\frac{1}{j\omega C}=j\omega L$$

It is effectively generalised resistance. Where $X$ is a positive value representing **reactance** such that $+jX$ implies inductance while $-jX$ implies capacitance:

$$Z=\frac{\bold V}{\bold I}=R\pm jX$$

**Admittance** is the inverse of impedance with units Siemens/mhos with factors **conductance** and **susceptance**:

$$Y=G+jB$$

Arranging equations yields

$$
G=\frac{R}{R^2+X^2} \\
B=-\frac{X}{R^2+X^2}
$$

### Steady state analysis

**Kirchoff's laws** only hold for phasor forms.

1. Convert to phasor forms
2. Solve phasor forms
3. Convert back to time domain

Superposition must be summed at the end only, although individual components can first be solved.

1. Convert to phasor forms
2. Solve each individual current/voltage that make KCL/KVL
3. Convert to time domain
4. Apply KCL/KVL

When applying source transformations, different equivalent circuits for **each frequency** must be calculated individually — reducing it to one equivalent circuit is not possible.

### Power

The average power is the integral average of instantaneous power:

$$P=\frac 1 T \int^T_0 p(t)dt$$

!!! tip
    The average of a sinusoid over its period is zero.

Alternatively, power can be calculated with magnitudes:

$$P=\frac 1 2\text{Re}[VI^*]=\frac 1 2 V_mI_m\cos(\theta_v-\theta_i)$$

The same rules for maximum power transfer apply with resistance, but with $Z_L$ as the **complex conjugate** of $Z_{Th}$. The maximum power has a shortcut formula:

$$P_{max}=\frac{|V_{Th}^2}{8R_{Th}}$$

The **effective value** of a sinusoid is its DC equivalent. It is the root mean square.

$$X_{rms}=\sqrt{\frac 1 T\int^T_0x^2dt}$$

The **apparent power** $S$ is the seemingly true power.

$$S=V_{rms}I_{rms}$$

The **power factor (pf)** is the required factor to take the apparent power into real power.

$$pf=\frac P S = \cos(\theta_v-\theta_i)$$

The **power factor angle** $\theta_v-\theta_i$ is the angle of local impedance between voltage and current.

$$Z=\frac{V_{rms}}{I_{rms}}\phase{\theta_v-\theta_i}=\frac{V_m}{I_m}\phase{\theta_v-\theta_i}$$

- A **leading** power factor has current lead voltage (capacitive)
- A **lagging** power factor has voltage lead current (inductive)
- A **unity** power factor has no phase shift

Complex power $\bold S$ stores more phase information where $\bold{V_{rms}}=V_{rms}\phase{\theta_v}$.

$$\bold S=\frac 1 2\bold{VI}^*=\bold{V_{rms}I^*_{rms}}$$

These have units volt-amperes (VA).

$$\bold S=V_{rms}I_{rms}\phase{\theta_v-\theta_i}=V_{rms}I_{rms}\cos(\theta_v-\theta_i)+jV_{rms}I_{rms}\sin(\theta_v-\theta_i)$$

The two components of complex power are actual power $P=I^2_{rms}R$ and reactive power $Q=I^2_{rms}X$, the latter with units VAR (volt-ampere reactive).

$$\bold S=P+jQ$$

Complex power still follows most DC laws:

$$\bold S=I^2_{rms}\bold Z=\frac{V^2_{rms}}{\bold Z^*}=\bold{V_{rms}I^*_{rms}}$$

All powers (instantaneous, real, reactive, and complex) are conserved, except for apparent power.
